#!/bin/bash
#
# Mandatory 3rd-parties switches
export HAVE_FREETYPE=yes
export HAVE_FTGL=yes
export HAVE_TCLTK=yes
# Optional 3rd-parties switches
export HAVE_FREEIMAGE=no
export HAVE_GL2PS=no
export HAVE_TBB=no
export HAVE_OPENCL=no
export HAVE_QT=no
export HAVE_VTK=yes
#
export CSF_OPT_INC="/opt/vtk6/include/vtk/:/usr/include/FTGL:/usr/include/freetype2:/usr/include:/usr/include:"
export CSF_OPT_LIB64="/opt/vtk6/lib/:::/usr/lib:/usr/lib:"
export CSF_OPT_BIN64=""
